(* ::Package:: *)

(* ::Title:: *)
(*HARDI Algorithms*)


(* ::Subtitle:: *)
(*Initialization File*)


(* ::Subsubtitle:: *)
(*Tom Dela Haije*)
(*Eindhoven University of Technology*)
(*\[Copyright]2011*)


(* ::Section:: *)
(*Preamble*)


(* :Title: HARDI Algorithms - Initialization *)

(* :Context: HARDIAlgorithms` *)

(* :Author: E.J. Creusen *)

(* :Email addres: E.J.Creusen@tue.nl *)

(* :Summary: Initialization file of the HARDI Algorithms package. *)

(* :Package Version: 0.4.0 *)

(* :Mathematica Version: 8.0 *)

(* :Copyright: 2011, Eindhoven University of Technology *)

(* :History:
	V. 0.1.0 March 2011, by T.C.J. Dela Haije. First version of the initialization file.
	V. 0.4.0 September 2011, by E.J. Creusen. Changed contact information and incremented version number. Changed name of differentiation package to Finite differences, and the finite differences package to Enhancements, to better suit their contents.
*)

(* :Keywords: 
	HARDI
	HARDI visualization
	Left-invariant diffusions
	Left-invariant erosions
	Group convolutions
	Finite differences
*)

(* :Limitations: *)

(* :Discussion:
	An export function needs to be added
	Once possible, the package will be adapted to work with DTITool standards
	Based on code by Tom Dela Haije, Eric Creusen and Mark Bruurmijn, and on theory by Remco Duits
*)


(* ::Section:: *)
(*Begin Package*)


BeginPackage["HARDIAlgorithms`"];


(* ::Section:: *)
(*Unprotecting Variables*)


Unprotect["HARDIAlgorithms`$*"]


(* ::Section:: *)
(*Package Code*)


(* ::Subsection:: *)
(*Version ID*)


$HARDIAlgorithmsVersion = "0.5.0 Beta";


(* ::Subsection:: *)
(*Contact Information*)


$Contact = Framed[Column[{
Style["E.J.Creusen\nEindhoven University of Technology\nBiomedical Image Analysis\nPO Box 513, 5600 MB Eindhoven", FontFamily -> "Arial"],
Button[Style["E.J.Creusen@tue.nl", FontFamily -> "Arial", FontColor -> Blue, Underlined], SystemOpen["mailto:E.J.Creusen@tue.nl"], Appearance -> None]
}], Background -> White];


(* ::Section:: *)
(*Protecting Variables*)


Protect["HARDIAlgorithms`$*"]


(* ::Section:: *)
(*End Package*)


EndPackage[]


(* ::Section:: *)
(*Package Declarations*)


(* ::Subsection:: *)
(*Common*)


DeclarePackage["HARDIAlgorithms`Common`",
{"ExtractOrientations","ExtractTopology","ExtractTessellation",
"ResetOrientations","ResetTopology","ResetFiniteDifferences",
"StandardColours",
"Rotate1","Rotate2","Rotate3",
"EulerAngles",
"SignPreservingPower","MinMaxNormalize","MinNormalize",
"RicianNoise"
}];


(* ::Subsection:: *)
(*Tessellation*)


DeclarePackage["HARDIAlgorithms`Tessellation`",
{"DefineTessellation"}];


(* ::Subsection:: *)
(*Visualization*)


DeclarePackage["HARDIAlgorithms`Visualization`",
{"ListHardiPlot"}];


(* ::Subsection:: *)
(*Finite Differences*)


DeclarePackage["HARDIAlgorithms`FiniteDifferences`",
{"GroupDifferences","UpwindGroupDifferences","SpatialInterpolate","AngularInterpolate"}];


(* ::Subsection:: *)
(*Enhancements*)


DeclarePackage["HARDIAlgorithms`Enhancements`",
{"ContourEnhancement","LeftInvariantDiffusion","ContourCompletion",
"GeneralContourCompletion","MorphologicalEnhancement","PeronaMalikEnhancement"}];


(* ::Subsection:: *)
(*Convolution*)


DeclarePackage["HARDIAlgorithms`Convolution`",
{"BuildKernel",
"ContourEnhancementTemplate","ErosionTemplate",
"ListGroupConvolve"}];


(* ::Section:: *)
(*Defaults*)


$DefaultPolyhedron = "Icosahedron";
$DefaultTessellationOrder = 3;


$RemoteKernelPath = "S:\\People\\Student\\Tom Dela Haije\\Kernels";
$LocalKernelPath = $UserDocumentsDirectory<>"\\Kernels";


(*$DefaultSpatialDifferentiationParameter = 0.88;
$DefaultAngularDifferentiationParameter = N[\[Pi]/25];*)


(* ::Section:: *)
(*Set Defaults*)


$Orientations = ExtractOrientations[$DefaultPolyhedron,$DefaultTessellationOrder];


$Topology = ExtractTopology[$DefaultPolyhedron,$DefaultTessellationOrder];


$Colours = StandardColours[$Orientations];
